@@ -4,7 +4,8 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#pragma once
+#ifndef MEDIATRANSPORTINTERFACE_H
+#define MEDIATRANSPORTINTERFACE_H
 
 #include "object.h"
 
@@ -40,3 +41,5 @@ public Q_SLOTS:
     void TryAcquire(const QDBusMessage &msg);
     void Release();
 };
+
+#endif
