@@ -108,10 +108,7 @@ ObexTransfer::ObexTransfer(const QString &path, const QVariantMap &properties)
 {
 }
 
-ObexTransfer::~ObexTransfer()
-{
-    delete d;
-}
+ObexTransfer::~ObexTransfer() = default;
 
 ObexTransferPtr ObexTransfer::toSharedPtr() const
 {
@@ -179,3 +176,6 @@ PendingCall *ObexTransfer::resume()
 }
 
 } // namespace BluezQt
+
+#include "moc_obextransfer.cpp"
+#include "moc_obextransfer_p.cpp"
