@@ -1,23 +1,9 @@
 /*
  * BluezQt - Asynchronous BlueZ wrapper library
  *
- * Copyright (C) 2014-2015 David Rosca <nowrep@gmail.com>
+ * SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #ifndef BLUEZQT_REQUEST_H
@@ -32,52 +18,53 @@ class QDBusMessage;
 namespace BluezQt
 {
 
+/*!
+ * \enum BluezQt::RequestOriginatingType
+ * \value OrgBluezAgent
+ * \value OrgBluezProfile
+ * \value OrgBluezObexAgent
+ * \value OrgBluezMediaEndpoint
+ */
 enum RequestOriginatingType {
     OrgBluezAgent,
     OrgBluezProfile,
     OrgBluezObexAgent,
-    OrgBluezMediaEndpoint
+    OrgBluezMediaEndpoint,
 };
 
-/**
- * @class BluezQt::Request request.h <BluezQt/Request>
- *
- * D-Bus request.
+/*!
+ * \inmodule BluezQt
+ * \class BluezQt::Request
+ * \inheaderfile BluezQt/Request
+ * \brief D-Bus request.
  *
  * This class represents a request from a Bluetooth daemon. It is a convenient
  * wrapper around QDBusMessage and easily allows sending replies and handling errors.
  *
- * @see Agent, ObexAgent, Profile
+ * \sa Agent, ObexAgent, Profile
  */
 template<typename T = void>
 class BLUEZQT_EXPORT Request
 {
 public:
-    /**
+    /*!
      * Creates a new Request object.
      */
     explicit Request();
 
-    /**
-     * Destroys a Request object.
-     */
     virtual ~Request();
 
-    /**
-     * Copy constructor.
-     *
-     * @param other
+    /*!
+     * Constructs a new Request object from \a other.
      */
     Request(const Request &other);
 
-    /**
-     * Copy assignment operator.
-     *
-     * @param other
+    /*!
+     * Copies the Request object from \a other.
      */
     Request &operator=(const Request &other);
 
-    /**
+    /*!
      * Accepts the request.
      *
      * This method should be called to send a reply to indicate
@@ -86,11 +73,11 @@ public:
      * In case the request is of type void, this method does not
      * take any parameter.
      *
-     * @param returnValue return value of request
+     * \a returnValue The return value of the request.
      */
     void accept(T returnValue) const;
 
-    /**
+    /*!
      * Rejects the request.
      *
      * This method should be called to send an error reply to
@@ -98,7 +85,7 @@ public:
      */
     void reject() const;
 
-    /**
+    /*!
      * Cancels the request.
      *
      * This method should be called to send an error reply to
